@@ -55,6 +55,27 @@ class TwoBranchMLPModel(nn.Sequential):
 		output = self.comb_branch(v_comb)
 		return output
 
+class TwoBranchKroneckerModel(nn.Sequential):
+	'''Implements a two branch neural network that first computes the kronecker product of the two embeddings and then passes the resulting vector to an MLP (terminating to a single output node)
+	'''
+	def __init__(self, config, instance_branch_model, target_branch_model):
+		super(TwoBranchKroneckerModel, self).__init__()
+		self.instance_branch_model = instance_branch_model
+		self.target_branch_model = target_branch_model
+
+		comb_dim = instance_branch_model[0][-2].out_features * target_branch_model[0][-2].out_features
+		# self.comb_branch = MLP(config, comb_dim, 1, config['comb_mlp_nodes_per_layer'], config['comb_mlp_branch_layers'], config['dropout_rate'], config['batch_norm'])
+		self.comb_branch = nn.Linear(comb_dim, 1)
+	
+	def forward(self, instance_features, target_features):
+		instance_embedding = self.instance_branch_model(instance_features)
+		target_embedding = self.target_branch_model(target_features)
+		# compute the Kronecker product
+		# v_comb = torch.kron(instance_embedding, target_embedding) # there is no dim option for a batch operation... 
+		v_comb = torch.stack([torch.kron(ai, bi) for ai, bi in zip(instance_embedding, target_embedding)], dim=0)
+		output = self.comb_branch(v_comb)
+		return output
+
 
 class DeepMTP:
 	''' Implements the training and inference logic of the DeepMTP framework. 
@@ -98,7 +119,7 @@ class DeepMTP:
 			1) The dot-product version: the two embedding vectors have the same size, so their dot-product is just computed.
 			2) The MLP version: the two embedding vectors (don't have to be of the same size) are concatenated and then passed through a series or fully connected layers.
 		'''
-		if self.config['enable_dot_product_version']:
+		if self.config['general_architecture_version'] == 'dot_product':
 			instance_branch_output_dim = self.config['embedding_size']
 			target_branch_output_dim = self.config['embedding_size']
 		else:
@@ -125,10 +146,12 @@ class DeepMTP:
 			self.target_branch_model = target_branch_model(self.config)
 
 		# initalize the two-branch neural network
-		if self.config['enable_dot_product_version']:
+		if self.config['general_architecture_version'] == 'dot_product':
 			self.deepMTP_model = TwoBranchDotProductModel(self.config, self.instance_branch_model, self.target_branch_model)
-		else:
+		elif self.config['general_architecture_version'] == 'mlp':
 			self.deepMTP_model = TwoBranchMLPModel(self.config, self.instance_branch_model, self.target_branch_model)
+		elif self.config['general_architecture_version'] == 'kronecker':
+			self.deepMTP_model = TwoBranchKroneckerModel(self.config, self.instance_branch_model, self.target_branch_model)
 
 		self.deepMTP_model.to(self.device)
 
@@ -206,25 +229,28 @@ class DeepMTP:
 
 			# calculate the performance
 			if ((mode=='test') or ((epoch % self.config['eval_every_n_epochs'] == 0) and (self.config['evaluate_val'])) or (self.config['metric_to_optimize_early_stopping']!='loss') or (self.config['num_epochs']-1 == epoch)):
-				if verbose: print('Calculating '+mode+' performance... ', end='')
-				results = get_performance_results(
-					mode, 
-					epoch,
-					instance_ids_arr, 
-					target_ids_arr, 
-					true_scores_arr, 
-					pred_scores_arr, 
-					self.config['validation_setting'],
-					self.config['problem_mode'],
-					self.config['metrics'],
-					self.config['metrics_average'],
-					verbose=self.config['results_verbose'],
-					per_target_verbose=self.config['eval_target_verbose'],
-    				per_instance_verbose=self.config['eval_instance_verbose'],
-					train_true_value=None,
-					scaler_per_target=None,
-				)
-				if verbose: print('Done')
+				if self.config['metrics']:
+					if verbose: print('Calculating '+mode+' performance... ', end='')
+					results = get_performance_results(
+						mode, 
+						epoch,
+						instance_ids_arr, 
+						target_ids_arr, 
+						true_scores_arr, 
+						pred_scores_arr, 
+						self.config['validation_setting'],
+						self.config['problem_mode'],
+						self.config['metrics'],
+						self.config['metrics_average'],
+						verbose=self.config['results_verbose'],
+						per_target_verbose=self.config['eval_target_verbose'],
+						per_instance_verbose=self.config['eval_instance_verbose'],
+						train_true_value=None,
+						scaler_per_target=None,
+					)
+					if verbose: print('Done')
+			
+			model.train()
 			
 			if mode != 'test':
 				results[mode+'_loss'] = np.mean(loss_arr)
@@ -241,11 +267,11 @@ class DeepMTP:
 		# val_dataset = BaseDataset(self.config, val_data['y'], val_data['X_instance'], val_data['X_target'])
 
 		# initialize the dataloaders
-		train_dataloader = DataLoader(BaseDataset(self.config, train_data['y'], train_data['X_instance'], train_data['X_target'], instance_transform=self.config['instance_train_transforms'], target_transform=self.config['target_train_transforms']), self.config['train_batchsize'], shuffle=True, num_workers=self.config['num_workers'])
+		train_dataloader = DataLoader(BaseDataset(self.config, train_data['y'], train_data['X_instance'], train_data['X_target'], instance_transform=self.config['instance_train_transforms'], target_transform=self.config['target_train_transforms']), self.config['train_batchsize'], shuffle=True, num_workers=self.config['num_workers'], pin_memory=True)
 		if val_data is not None:
-			val_dataloader = DataLoader(BaseDataset(self.config, val_data['y'], val_data['X_instance'], val_data['X_target'], instance_transform=self.config['instance_inference_transforms'], target_transform=self.config['target_inference_transforms']), self.config['val_batchsize'], shuffle=False, num_workers=self.config['num_workers'])
+			val_dataloader = DataLoader(BaseDataset(self.config, val_data['y'], val_data['X_instance'], val_data['X_target'], instance_transform=self.config['instance_inference_transforms'], target_transform=self.config['target_inference_transforms']), self.config['val_batchsize'], shuffle=False, num_workers=self.config['num_workers'], pin_memory=True)
 		if test_data is not None:
-			test_dataloader = DataLoader(BaseDataset(self.config, test_data['y'], test_data['X_instance'], test_data['X_target'], instance_transform=self.config['instance_inference_transforms'], target_transform=self.config['target_inference_transforms']), self.config['val_batchsize'], shuffle=False, num_workers=self.config['num_workers'])
+			test_dataloader = DataLoader(BaseDataset(self.config, test_data['y'], test_data['X_instance'], test_data['X_target'], instance_transform=self.config['instance_inference_transforms'], target_transform=self.config['target_inference_transforms']), self.config['val_batchsize'], shuffle=False, num_workers=self.config['num_workers'], pin_memory=True)
 
 		if self.config['verbose']: print('Starting training...')
 
@@ -308,7 +334,7 @@ class DeepMTP:
 					target_ids_arr.extend(batch['target_id'].numpy())
 
 			# calculate performance metrics on the training set
-			if ((self.config['evaluate_train']) and ((epoch % self.config['eval_every_n_epochs'] == 0) or (self.config['num_epochs']-1 == epoch ))):
+			if ((self.config['evaluate_train']) and self.config['metrics'] and ((epoch % self.config['eval_every_n_epochs'] == 0) or (self.config['num_epochs']-1 == epoch ))):
 				train_results = get_performance_results(
 					'train', 
 					epoch,
@@ -345,7 +371,8 @@ class DeepMTP:
 
 			# generate predictions for the validation set. This needs to be done in order to early stop and to select between configurations
 			if self.config['verbose']: print('  Validating... ', end='')
-			val_results = self.inference(self.deepMTP_model, val_dataloader, 'val', epoch, verbose=self.config['verbose'])
+			with torch.set_grad_enabled(False):
+				val_results = self.inference(self.deepMTP_model, val_dataloader, 'val', epoch, verbose=self.config['verbose'])
 			if self.config['verbose']: print('Done')
 
 			# update val_run_story_table
@@ -444,7 +471,7 @@ class DeepMTP:
 
 	def predict(self, data, return_predictions=False, verbose=False):
 		self.deepMTP_model.to(self.device)
-		dataloader = DataLoader(BaseDataset(self.config, data['y'], data['X_instance'], data['X_target'], instance_transform=self.config['instance_inference_transforms'], target_transform=self.config['target_inference_transforms']), self.config['val_batchsize'], shuffle=False, num_workers=self.config['num_workers'])
+		dataloader = DataLoader(BaseDataset(self.config, data['y'], data['X_instance'], data['X_target'], instance_transform=self.config['instance_inference_transforms'], target_transform=self.config['target_inference_transforms']), self.config['val_batchsize'], shuffle=False, num_workers=self.config['num_workers'], pin_memory=True)
 		return self.inference(self.deepMTP_model, dataloader, '', 0, return_predictions=True, verbose=verbose)
 
 	def save_model(self, verbose=False):
